@@ -26,21 +26,20 @@ from ._abc import (
 from ._admin import (
     _Admin,
     _Balance,
-    _CloudProvider,
     _Cluster,
     _ClusterUser,
     _ClusterUserRoleType,
     _ClusterUserWithInfo,
-    _ConfigCluster,
-    _NodePool,
     _Org,
     _OrgCluster,
     _OrgUser,
     _OrgUserRoleType,
     _OrgUserWithInfo,
+    _Project,
+    _ProjectUser,
+    _ProjectUserRoleType,
+    _ProjectUserWithInfo,
     _Quota,
-    _Storage,
-    _StorageInstance,
     _UserInfo,
 )
 from ._bucket_base import (
@@ -53,6 +52,39 @@ from ._bucket_base import (
 )
 from ._buckets import Buckets
 from ._client import Client, Preset
+from ._clusters import (
+    _AWSCloudProvider,
+    _AWSStorage,
+    _AWSStorageOptions,
+    _AzureCloudProvider,
+    _AzureReplicationType,
+    _AzureStorage,
+    _AzureStorageOptions,
+    _AzureStorageTier,
+    _CloudProvider,
+    _CloudProviderOptions,
+    _CloudProviderType,
+    _Clusters,
+    _ClusterStatus,
+    _ConfigCluster,
+    _EFSPerformanceMode,
+    _EFSThroughputMode,
+    _GoogleCloudProvider,
+    _GoogleFilestoreTier,
+    _GoogleStorage,
+    _GoogleStorageOptions,
+    _NodePool,
+    _NodePoolOptions,
+    _OnPremCloudProvider,
+    _ResourcePreset,
+    _Storage,
+    _StorageInstance,
+    _StorageOptions,
+    _TPUPreset,
+    _VCDCloudProvider,
+    _VCDCloudProviderOptions,
+    _VCDStorage,
+)
 from ._config import Config
 from ._config_factory import (
     CONFIG_ENV_NAME,
@@ -111,7 +143,7 @@ from ._url_utils import CLUSTER_SCHEMES as SCHEMES
 from ._users import Action, Permission, Quota, Share, Users
 from ._utils import _ContextManager, find_project_root
 
-__version__ = "22.7.0"
+__version__ = "22.7.1"
 
 
 __all__ = (
@@ -205,24 +237,54 @@ __all__ = (
     "VersionChecker",
     "Volume",
     "VolumeParseResult",
+    "_AWSCloudProvider",
+    "_AWSStorage",
+    "_AWSStorageOptions",
     "_Admin",
+    "_AzureCloudProvider",
+    "_AzureReplicationType",
+    "_AzureStorage",
+    "_AzureStorageOptions",
+    "_AzureStorageTier",
     "_Balance",
     "_CloudProvider",
+    "_CloudProviderOptions",
+    "_CloudProviderType",
     "_Cluster",
+    "_ClusterStatus",
     "_ClusterUser",
     "_ClusterUserRoleType",
     "_ClusterUserWithInfo",
+    "_Clusters",
     "_ConfigCluster",
+    "_EFSPerformanceMode",
+    "_EFSThroughputMode",
+    "_GoogleCloudProvider",
+    "_GoogleFilestoreTier",
+    "_GoogleStorage",
+    "_GoogleStorageOptions",
     "_NodePool",
+    "_NodePoolOptions",
+    "_OnPremCloudProvider",
     "_Org",
     "_OrgCluster",
     "_OrgUser",
     "_OrgUserRoleType",
     "_OrgUserWithInfo",
+    "_Project",
+    "_ProjectUser",
+    "_ProjectUserRoleType",
+    "_ProjectUserWithInfo",
     "_Quota",
+    "_ResourcePreset",
     "_Storage",
     "_StorageInstance",
+    "_StorageOptions",
+    "_TPUPreset",
     "_UserInfo",
+    "_VCDCloudProvider",
+    "_VCDCloudProviderOptions",
+    "_VCDStorage",
     "__version__",
     "find_project_root",
     "gen_trace_id",
