@@ -6,6 +6,8 @@ from typing import (
     AbstractSet,
     Any,
     AsyncIterator,
+    Awaitable,
+    Callable,
     Dict,
     Iterable,
     Mapping,
@@ -45,7 +47,12 @@ from ._file_utils import FileSystem, FileTransferer, LocalFS, rm
 from ._parser import Parser
 from ._rewrite import rewrite_module
 from ._url_utils import _extract_path, normalize_local_path_uri
-from ._utils import NoPublicConstructor, asyncgeneratorcontextmanager
+from ._utils import (
+    ORG_NAME_SENTINEL,
+    NoPublicConstructor,
+    OrgNameSentinel,
+    asyncgeneratorcontextmanager,
+)
 
 
 class BucketFS(FileSystem[PurePosixPath]):
@@ -116,10 +123,14 @@ class BucketFS(FileSystem[PurePosixPath]):
                 yield chunk
 
     async def write_chunks(
-        self, path: PurePosixPath, body: AsyncIterator[bytes], offset: int = 0
+        self,
+        path: PurePosixPath,
+        body: AsyncIterator[bytes],
+        offset: int = 0,
+        progress: Optional[Callable[[int], Awaitable[None]]] = None,
     ) -> None:
         assert offset == 0, "Buckets do not support offset write"
-        await self._provider.put_blob(self._as_file_key(path), body)
+        await self._provider.put_blob(self._as_file_key(path), body, progress)
 
     @asyncgeneratorcontextmanager
     async def iter_dir(self, path: PurePosixPath) -> AsyncIterator[PurePosixPath]:
@@ -222,13 +233,15 @@ class Buckets(metaclass=NoPublicConstructor):
         self,
         name: Optional[str] = None,
         cluster_name: Optional[str] = None,
-        org_name: Optional[str] = None,
+        org_name: Union[Optional[str], OrgNameSentinel] = ORG_NAME_SENTINEL,
     ) -> Bucket:
         url = self._get_buckets_url(cluster_name)
         auth = await self._config._api_auth()
         data = {
             "name": name,
-            "org_name": org_name or self._config.org_name,
+            "org_name": org_name
+            if not isinstance(org_name, OrgNameSentinel)
+            else self._config.org_name,
         }
         async with self._core.request("POST", url, auth=auth, json=data) as resp:
             payload = await resp.json()
@@ -241,7 +254,7 @@ class Buckets(metaclass=NoPublicConstructor):
         credentials: Mapping[str, str],
         name: Optional[str] = None,
         cluster_name: Optional[str] = None,
-        org_name: Optional[str] = None,
+        org_name: Union[Optional[str], OrgNameSentinel] = ORG_NAME_SENTINEL,
     ) -> Bucket:
         url = self._get_buckets_url(cluster_name) / "import" / "external"
         auth = await self._config._api_auth()
@@ -250,7 +263,9 @@ class Buckets(metaclass=NoPublicConstructor):
             "provider": provider.value,
             "provider_bucket_name": provider_bucket_name,
             "credentials": credentials,
-            "org_name": org_name or self._config.org_name,
+            "org_name": org_name
+            if not isinstance(org_name, OrgNameSentinel)
+            else self._config.org_name,
         }
         async with self._core.request("POST", url, auth=auth, json=data) as resp:
             payload = await resp.json()
