@@ -118,7 +118,7 @@ async def mock_for_login_factory(
                             "name": "gpu-small",
                             "credits_per_hour": "10",
                             "cpu": 7,
-                            "memory_mb": 30 * 1024,
+                            "memory": 30 * 2**30,
                             "gpu": 1,
                             "gpu_model": "nvidia-tesla-k80",
                         },
@@ -126,7 +126,7 @@ async def mock_for_login_factory(
                             "name": "gpu-large",
                             "credits_per_hour": "10",
                             "cpu": 7,
-                            "memory_mb": 60 * 1024,
+                            "memory": 60 * 2**30,
                             "gpu": 1,
                             "gpu_model": "nvidia-tesla-v100",
                         },
@@ -134,13 +134,13 @@ async def mock_for_login_factory(
                             "name": "cpu-small",
                             "credits_per_hour": "10",
                             "cpu": 2,
-                            "memory_mb": 2 * 1024,
+                            "memory": 2 * 2**30,
                         },
                         {
                             "name": "cpu-large",
                             "credits_per_hour": "10",
                             "cpu": 3,
-                            "memory_mb": 14 * 1024,
+                            "memory": 14 * 2**30,
                         },
                     ],
                 }
