@@ -152,7 +152,7 @@ async def test_get_server_config_with_token(
                         "name": "gpu-small",
                         "credits_per_hour": "10",
                         "cpu": 7,
-                        "memory_mb": 30 * 1024,
+                        "memory": 30 * 2**30,
                         "gpu": 1,
                         "gpu_model": "nvidia-tesla-k80",
                     },
@@ -160,7 +160,7 @@ async def test_get_server_config_with_token(
                         "name": "gpu-large",
                         "credits_per_hour": "10",
                         "cpu": 7,
-                        "memory_mb": 60 * 1024,
+                        "memory": 60 * 2**30,
                         "gpu": 1,
                         "gpu_model": "nvidia-tesla-v100",
                     },
@@ -168,19 +168,19 @@ async def test_get_server_config_with_token(
                         "name": "cpu-small",
                         "credits_per_hour": "10",
                         "cpu": 2,
-                        "memory_mb": 2 * 1024,
+                        "memory": 2 * 2**30,
                     },
                     {
                         "name": "cpu-large",
                         "credits_per_hour": "10",
                         "cpu": 3,
-                        "memory_mb": 14 * 1024,
+                        "memory": 14 * 2**30,
                     },
                     {
                         "name": "cpu-large-p",
                         "credits_per_hour": "10",
                         "cpu": 3,
-                        "memory_mb": 14 * 1024,
+                        "memory": 14 * 2**30,
                         "scheduler_enabled": True,
                         "preemptible_node": True,
                     },
@@ -224,27 +224,27 @@ async def test_get_server_config_with_token(
                     "gpu-small": Preset(
                         credits_per_hour=Decimal("10"),
                         cpu=7,
-                        memory_mb=30 * 1024,
+                        memory=30 * 2**30,
                         gpu=1,
                         gpu_model="nvidia-tesla-k80",
                     ),
                     "gpu-large": Preset(
                         credits_per_hour=Decimal("10"),
                         cpu=7,
-                        memory_mb=60 * 1024,
+                        memory=60 * 2**30,
                         gpu=1,
                         gpu_model="nvidia-tesla-v100",
                     ),
                     "cpu-small": Preset(
-                        credits_per_hour=Decimal("10"), cpu=2, memory_mb=2 * 1024
+                        credits_per_hour=Decimal("10"), cpu=2, memory=2 * 2**30
                     ),
                     "cpu-large": Preset(
-                        credits_per_hour=Decimal("10"), cpu=3, memory_mb=14 * 1024
+                        credits_per_hour=Decimal("10"), cpu=3, memory=14 * 2**30
                     ),
                     "cpu-large-p": Preset(
                         credits_per_hour=Decimal("10"),
                         cpu=3,
-                        memory_mb=14 * 1024,
+                        memory=14 * 2**30,
                         scheduler_enabled=True,
                         preemptible_node=True,
                     ),
